@@ -64,8 +64,10 @@ class PictureModes(Enum):
     cinema = b"01"
     natural = b"03"
     hdr = b"04"
-    # unsupported
-    THX = b"06"
+    THX = b"06" # unsupported
+    filmmaker = b"7" # requires firmware 2.0
+    frame_adapt_hdr2 = b"8" # requires firmware 2.0
+    frame_adapt_hdr3 = b"9" # requires firmware 2.0
     frame_adapt_hdr = b"0B"
     user1 = b"0C"
     user2 = b"0D"
@@ -154,6 +156,7 @@ class LaserDimModes(Enum):
     off = b"0"
     auto1 = b"1"
     auto2 = b"2"
+    auto3 = b"3" # requires firmware 2.0
 
 
 class EnhanceModes(Enum):
